#!/bin/sh

#########################################################################
# 
# Copyright(c) 2004, 2005 Intel Corporation. All rights reserved. 
#
# This program is free software; you can redistribute it and/or modify 
# it under the terms of the GNU General Public License as published by 
# the Free Software Foundation; either version 2 of the License, or (at
# your option) any later version.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranty of 
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
# General Public License for more details.
# 
# You should have received a copy of the GNU General Public License 
# along with this program; if not, write to the Free Software Foundation,
# Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
# 
# The full GNU General Public License is included in this distribution in 
# the file called LICENSE.
#
#########################################################################

# appver.sh
# This script ensures that the applications comprising the Basic Office 
# Automation stack are installed with the appropriate versions and 
# supporting packages. 
#
# $Id: appver.sh,v 1.13 2004/11/04 21:33:49 dkeskar Exp $

# ToDo: 
# n2h -- Flash player - check in mozilla plugin directory (Red Hat only)
# legal verification of all strings 
# 

# Usage & version info for script itself
usage="\

Usage: $0 [OPTIONS]
Check that the applications for Basic Office Automation are installed.
Ensures the appropriate versions and dependencies are met. 

Options:
  -h, --help                print this help, then exit
  -V, --version             print version number, then exit
  -v, --verbose             print details during processing
"

help="\
Type '$0 --help' for more information."

version="\
appver 1.0 Intel(R) Quick Start Kit for Linux Release 1.0"

# Distribution-specific install guidance
# 0 = Red Hat, 1 = Suse, 2 = Red Flag
dInstallMsg[0]="\
Use the \"redhat-config-packages\" tool, available from the main menu\\nat System Tools | Add or Remove Applications."

dInstallMsg[1]="\
Use the \"Yast2\" tool, available from the main menu Control Center."

dInstallMsg[2]="\
Use the RPM \"Installation Tool\" available from the main menu at\\nApplications | Accessories.
"

# script messages
beginmsg="
Checking versions and dependencies for Basic Office Automation applications.
"
successmsg="\
Success!\\nThe Basic Office Automation packages are installed with correct versions.
"
actionmsg="\
Note:\\nPlease follow steps below for a complete Basic Office Automation system.
"
installmsg="\
Install these currently missing packages.\\nIn most cases, these packages may be part of the Linux distribution CD.
"
versionmsg="\
Ensure these packages have the given versions.\\n
"

# specific messages
redhat1="\
  On Red Hat Desktop, Flash Player & RealPlayer are not installed by default.
"
redflag1="\
  On Red Flag, insert disk 3, wait for autorun and select Open Office install.
"

# Flags, reset initially
verbose=0;
verflag=0
instflag=0

# Logging Functions
function err_exit {
	echo -e "Error: $1"
	exit 3
}

function info_log {
	if (($verbose != 0)); then
		echo -e $1
	fi
}

# Process command line arguments
while test $# -gt 0; do
	case $1 in 
		--version | -V ) 
			echo "$version"; exit 0 ;;
		--help | -h ) 
			echo "$usage"; exit 0;;
		--verbose | -v ) 
			verbose=1
			;;
		-* ) 
			exec >&2
			echo "$0: invalid option $1"
			echo "$help"
			exit 1 ;;
		* ) 
			break
			;;
	esac
	shift
done

# Begin ....
echo $version
echo $beginmsg

# Gather basic information
# ensure we are running on Linux
os="Linux"
if test "`uname`" != "$os"; then
	err_exit "Unsupported environment: Need $os"
fi
# get kernel version 
kernelver=`uname -r`
# check that rpm is available and note its version
rpmver=`rpm --version`
rpmver=`echo $rpmver | cut -d " " -f 3`
# get distro information using /proc/version 
verfile="/proc/version"
if test -r "$verfile"; then
	diststr=`cat $verfile | cut -d \( -f 4 | cut -d \) -f 1`
	case "$diststr" in 
	Red*Hat*Linux* )
	# match with "Red Hat Linux 3.2.3-42, not 3.2.2-5"
	# Assume this will change by the time of GA, ignore buildnum
		distro=0
		# pattern match w/ 2.4.21-20.EL
		info_log "Red Hat $diststr"
		if test "$rpmver" != '4.2'; then
			if test "$rpmver" != '4.2.3'; then 
				err_exit "Unsupported RPM version $rpmver. Expect 4.2.3"
			fi
		fi
		# package info
		pkglistfile="RH3_pkg"
		;;
	SuSE*Linux* )
	# Check for specific version
		distro=1
		# pattern match w/ 2.6.5-7.108-default
		info_log "Novell $diststr"
		if test "$rpmver" != '4.1.1'; then
			err_exit "Unsupported RPM version $rpmver. Expect 4.1.1"
		fi
		# package info
		pkglistfile="NLD9_pkg"
		;;
	Asianux* )
	# Check for specific version
		distro=2
		# pattern match w/ 2.4.26-0.11
		info_log "Red Flag $diststr"
		if test "$rpmver" != '4.2.1'; then
			err_exit "Unsupported RPM version $rpmver. Expect 4.2.1"
		fi
		# package info
		pkglistfile="RF41_pkg"
		;;
	* )
		err_exit "Unsupported distribution. Please refer to documentation"
		;;
	esac
else 
	err_exit "Unknown distribution. $0 exiting"
fi


# Package and version information is in a file per distro.
exec 3< "$pkglistfile"

echo -n Please wait...
info_log " "
i=0
while read -u 3 pkgver pkg ver loc; do 
	# for each expected package, ensure installed with correct version
	msg=`rpm -q $pkgver`
	if test "$msg" != "$pkgver"; then
		info_log "\\tnot ok\\t\\t$pkgver"
		msg=`rpm -q $pkg`
		if test "$msg" == "package $pkg is not installed"; then
			# package not installed
			instflag=1
			info_log "-->Need to install $pkg"
			instpkg="$instpkg\\n + $pkgver"
			if [[ $loc != "o" && $loc != "cd" ]]; then 
				instpkg="$instpkg  (See $loc)"
			fi
		else 
			# version mismatch
			verflag=1
			info_log "-->Expect $pkgver, found $msg"
			verpkg="$verpkg\\n ~ $pkgver\\t(found $msg)"
		fi
		# remember this for later (a summary)
	else 
		info_log "\\tok\\t\\t$pkgver"
	fi
	let i=i+1
	if (($verbose == 0 && i % 10 == 0)); then
		# show progress in quiet mode
		echo -n .
	fi
done

# Result messages
echo Done.
if (($instflag == 0 && $verflag == 0)); then
	echo -e $successmsg
else 
	echo "*****************************************************"
	echo -e $actionmsg
	echo "*****************************************************"
	if (($instflag)); then
		echo 
		echo ----------------- Packages Missing -----------------
		echo -e $installmsg
		echo -e $instpkg
		echo ----------------------------------------------------
	fi
	if (($verflag)); then
		echo
		echo ----------------- Package Versions -----------------
		echo -e $versionmsg
		echo -e $verpkg
		echo ----------------------------------------------------
	fi
	echo -e ${dInstallMsg[$distro]}
	echo 
fi


#end
